Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Command ¶
type Command struct {
Command string
Env []string
Stdin io.Reader
Stdout io.Writer
Stderr io.Writer
}
Command holds the input and output data for a command
type CommandOutput ¶
CommandOutput is the buffer contents of a completed command
type SSHClient ¶
type SSHClient struct {
// contains filtered or unexported fields
}
SSHClient forms the external type
func NewSSHClient ¶
NewSSHClient simple constructor
func (*SSHClient) Command ¶
func (s *SSHClient) Command(cmdString string) (*CommandOutput, error)
Command takes string and inputs to stdin
type ShellConnection ¶
type ShellConnection interface {
Execute(*Command) (*Command, error)
Command(string) (*CommandOutput, error)
}
ShellConnection represents local, remote or fake unix shell interactions
Click to show internal directories.
Click to hide internal directories.